docx\_parser\_converter.docx\_parsers.styles.paragraph\_properties\_parser module
=================================================================================

.. automodule:: docx_parser_converter.docx_parsers.styles.paragraph_properties_parser
   :members:
   :undoc-members:
   :show-inheritance:
